@@ -384,17 +384,13 @@ admin (argc, argv)
     /* The use of `cvs admin -k' is unrestricted.  However, any other
        option is restricted if the group CVS_ADMIN_GROUP exists on the
        server.  */
-    if (
-# ifdef CLIENT_SUPPORT
-        /* This is only "secure" on the server, since the user could edit the
-	 * RCS file on a local host, but some people like this kind of
-	 * check anyhow.  The alternative would be to check only when
-	 * (server_active) rather than when not on the client.
-	 */
-        !current_parsed_root->isremote &&
-# endif	/* CLIENT_SUPPORT */
-        !only_k_option
-	&& (grp = getgrnam(CVS_ADMIN_GROUP)) != NULL)
+    /* This is only "secure" on the server, since the user could edit the
+     * RCS file on a local host, but some people like this kind of
+     * check anyhow.  The alternative would be to check only when
+     * (server_active) rather than when not on the client.
+     */
+    if (!current_parsed_root->isremote && !only_k_option &&
+	(grp = getgrnam(CVS_ADMIN_GROUP)) != NULL)
     {
 #ifdef HAVE_GETGROUPS
 	gid_t *grps;
@@ -821,6 +817,13 @@ admin_fileproc (callerdat, finfo)
 		{
 		    tag = xstrdup (arg + 2);
 		    rev = RCS_head (rcs);
+		    if (!rev)
+		    {
+			error (0, 0, "No head revision in archive file `%s'.",
+			       rcs->path);
+			status = 1;
+			continue;
+		    }
 		}
 		else
 		{
