@@ -136,7 +136,6 @@ my_module (db, mname, m_type, msg, callback_proc, where, shorten,
     char *mwhere = NULL;
     char *mfile = NULL;
     char *spec_opt = NULL;
-    char *xvalue = NULL;
     int alias = 0;
     datum key, val;
     char *cp;
@@ -376,6 +375,7 @@ my_module (db, mname, m_type, msg, callback_proc, where, shorten,
 	    /* mwhere gets just the module name */
 	    mwhere = xstrdup (mname);
 	    mfile = cp + 1;
+	    assert (strlen (mfile));
 
 	    /* put the / back in mname */
 	    *cp = '/';
@@ -749,7 +749,7 @@ module `%s' is a request for a file in a module which is not a directory",
 		err += run_exec (RUN_TTY, RUN_TTY, RUN_TTY, RUN_NORMAL);
 		free (expanded_path);
 	    }
-	    free (real_prog);
+	    if (real_prog) free (real_prog);
 	}
     }
 
@@ -770,8 +770,6 @@ module `%s' is a request for a file in a module which is not a directory",
     if (value != NULL)
 	free (value);
 
-    if (xvalue != NULL)
-	free (xvalue);
     return (err);
 }
 
