@@ -14,6 +14,7 @@
 #include "cvs.h"
 #include "getline.h"
 #include <assert.h>
+#include "history.h"
 
 extern char *logHistory;
 
@@ -45,6 +46,8 @@ Parse_Info (infofile, repository, callproc, all)
     const char *srepos;
     const char *regex_err;
 
+    assert (repository);
+
     if (current_parsed_root == NULL)
     {
 	/* XXX - should be error maybe? */
@@ -275,8 +278,7 @@ parse_config (cvsroot)
 	       value, currently at least.  */
 	    error (0, errno, "cannot open %s", infopath);
 	}
-	free (infopath);
-	return 0;
+	goto set_defaults_and_return;
     }
 
     while (getline (&line, &line_allocated, fp_info) >= 0)
@@ -400,8 +402,8 @@ warning: this CVS does not support PreservePermissions");
 	{
 	    if (strcmp (p, "all") != 0)
 	    {
-		logHistory=xmalloc(strlen (p) + 1);
-		strcpy (logHistory, p);
+		if (logHistory) free (logHistory);
+		logHistory = xstrdup (p);
 	    }
 	}
 	else if (strcmp (line, "RereadLogAfterVerify") == 0)
@@ -441,12 +443,17 @@ warning: this CVS does not support PreservePermissions");
 	error (0, errno, "cannot close %s", infopath);
 	goto error_return;
     }
+set_defaults_and_return:
+    if (!logHistory)
+	logHistory = xstrdup (ALL_HISTORY_REC_TYPES);
     free (infopath);
     if (line != NULL)
 	free (line);
     return 0;
 
  error_return:
+    if (!logHistory)
+	logHistory = xstrdup (ALL_HISTORY_REC_TYPES);
     if (infopath != NULL)
 	free (infopath);
     if (line != NULL)
